"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


EmbeddingDtype = Literal["float", "int8", "uint8", "binary", "ubinary"]
